@@ -17,11 +17,18 @@
 
 import copy
 
+from oslo_config import cfg
+
+from sahara.conductor import resource as r
 from sahara.db import base as db_base
+from sahara.service.castellan import utils as key_manager
+from sahara.service import shares
 from sahara.utils import configs
 from sahara.utils import crypto
 
 
+CONF = cfg.CONF
+
 CLUSTER_DEFAULTS = {
     "cluster_configs": {},
     "status": "undefined",
@@ -154,12 +161,21 @@ class ConductorManager(db_base.Base):
         """Return the cluster or None if it does not exist."""
         return self.db.cluster_get(context, cluster, show_progress)
 
-    def cluster_get_all(self, context, **kwargs):
+    def cluster_get_all(self, context, regex_search=False, **kwargs):
         """Get all clusters filtered by **kwargs.
 
-        e.g. cluster_get_all(plugin_name='vanilla', hadoop_version='1.1')
+        :param context: The context, and associated authentication, to use with
+                        this operation
+
+        :param regex_search: If True, enable regex matching for filter
+                             values. See the user guide for more information
+                             on how regex matching is handled. If False,
+                             no regex matching is done.
+
+        :param kwargs: Specifies values for named fields by which
+                       to constrain the search
         """
-        return self.db.cluster_get_all(context, **kwargs)
+        return self.db.cluster_get_all(context, regex_search, **kwargs)
 
     def cluster_create(self, context, values):
         """Create a cluster from the values dictionary."""
@@ -183,6 +199,7 @@ class ConductorManager(db_base.Base):
             del c_tmpl['id']
             del c_tmpl['is_public']
             del c_tmpl['is_protected']
+            del c_tmpl['tenant_id']
 
             # updating with cluster_template values
             merged_values.update(c_tmpl)
@@ -203,7 +220,28 @@ class ConductorManager(db_base.Base):
     def cluster_update(self, context, cluster, values):
         """Set the given properties on cluster and update it."""
         values = copy.deepcopy(values)
-        return self.db.cluster_update(context, cluster, values)
+        update_shares = values.get('shares')
+        if update_shares:
+            original_shares = (
+                self.db.cluster_get(context, cluster).get('shares', []))
+
+        updated_cluster = self.db.cluster_update(context, cluster, values)
+        if update_shares:
+            for share in update_shares:
+                # Only call mount_shares if we have new shares to mount.
+                # We only need one positive case to bother calling mount_shares
+                if share not in original_shares:
+                    shares.mount_shares(r.ClusterResource(updated_cluster))
+                    break
+            # Any shares that were on the original, but not on the updated
+            # list will be unmounted
+            unmount_list = [share for share in original_shares
+                            if share not in update_shares]
+            if len(unmount_list) > 0:
+                shares.unmount_shares(r.ClusterResource(updated_cluster),
+                                      unmount_list)
+
+        return updated_cluster
 
     def cluster_destroy(self, context, cluster):
         """Destroy the cluster or raise if it does not exist."""
@@ -261,13 +299,22 @@ class ConductorManager(db_base.Base):
         """Return the cluster_template or None if it does not exist."""
         return self.db.cluster_template_get(context, cluster_template)
 
-    def cluster_template_get_all(self, context, **kwargs):
+    def cluster_template_get_all(self, context, regex_search=False, **kwargs):
         """Get all cluster templates filtered by **kwargs.
 
-        e.g.  cluster_template_get_all(plugin_name='vanilla',
-                                       hadoop_version='1.1')
+        :param context: The context, and associated authentication, to use with
+                        this operation
+
+        :param regex_search: If True, enable regex matching for filter
+                             values. See the user guide for more information
+                             on how regex matching is handled. If False,
+                             no regex matching is done.
+
+        :param kwargs: Specifies values for named fields by which
+                       to constrain the search
         """
-        return self.db.cluster_template_get_all(context, **kwargs)
+        return self.db.cluster_template_get_all(context,
+                                                regex_search, **kwargs)
 
     def cluster_template_create(self, context, values):
         """Create a cluster_template from the values dictionary."""
@@ -280,13 +327,13 @@ class ConductorManager(db_base.Base):
         return self.db.cluster_template_create(context, values)
 
     def cluster_template_destroy(self, context, cluster_template,
-                                 ignore_default=False):
+                                 ignore_prot_on_def=False):
         """Destroy the cluster_template or raise if it does not exist."""
         self.db.cluster_template_destroy(context, cluster_template,
-                                         ignore_default)
+                                         ignore_prot_on_def)
 
     def cluster_template_update(self, context, id, values,
-                                ignore_default=False):
+                                ignore_prot_on_def=False):
         """Update a cluster_template from the values dictionary."""
         values = copy.deepcopy(values)
         values['tenant_id'] = context.tenant_id
@@ -295,7 +342,8 @@ class ConductorManager(db_base.Base):
         if 'node_groups' in values:
             values['node_groups'] = self._populate_node_groups(context, values)
 
-        return self.db.cluster_template_update(context, values, ignore_default)
+        return self.db.cluster_template_update(context, values,
+                                               ignore_prot_on_def)
 
     # Node Group Template ops
 
@@ -303,13 +351,23 @@ class ConductorManager(db_base.Base):
         """Return the Node Group Template or None if it does not exist."""
         return self.db.node_group_template_get(context, node_group_template)
 
-    def node_group_template_get_all(self, context, **kwargs):
+    def node_group_template_get_all(self,
+                                    context, regex_search=False, **kwargs):
         """Get all NodeGroupTemplates filtered by **kwargs.
 
-        e.g.  node_group_template_get_all(plugin_name='vanilla',
-                                          hadoop_version='1.1')
+        :param context: The context, and associated authentication, to use with
+                        this operation
+
+        :param regex_search: If True, enable regex matching for filter
+                             values. See the user guide for more information
+                             on how regex matching is handled. If False,
+                             no regex matching is done.
+
+        :param kwargs: Specifies values for named fields by which
+                       to constrain the search
         """
-        return self.db.node_group_template_get_all(context, **kwargs)
+        return self.db.node_group_template_get_all(context,
+                                                   regex_search, **kwargs)
 
     def node_group_template_create(self, context, values):
         """Create a Node Group Template from the values dictionary."""
@@ -320,20 +378,20 @@ class ConductorManager(db_base.Base):
         return self.db.node_group_template_create(context, values)
 
     def node_group_template_destroy(self, context, node_group_template,
-                                    ignore_default=False):
+                                    ignore_prot_on_def=False):
         """Destroy the Node Group Template or raise if it does not exist."""
         self.db.node_group_template_destroy(context, node_group_template,
-                                            ignore_default)
+                                            ignore_prot_on_def)
 
     def node_group_template_update(self, context, id, values,
-                                   ignore_default=False):
+                                   ignore_prot_on_def=False):
         """Update a Node Group Template from the values dictionary."""
         values = copy.deepcopy(values)
         values['tenant_id'] = context.tenant_id
         values['id'] = id
 
         return self.db.node_group_template_update(context, values,
-                                                  ignore_default)
+                                                  ignore_prot_on_def)
 
     # Data Source ops
 
@@ -341,12 +399,21 @@ class ConductorManager(db_base.Base):
         """Return the Data Source or None if it does not exist."""
         return self.db.data_source_get(context, data_source)
 
-    def data_source_get_all(self, context, **kwargs):
+    def data_source_get_all(self, context, regex_search=False, **kwargs):
         """Get all Data Sources filtered by **kwargs.
 
-        e.g.  data_source_get_all(name='myfile', type='swift')
+        :param context: The context, and associated authentication, to use with
+                        this operation
+
+        :param regex_search: If True, enable regex matching for filter
+                             values. See the user guide for more information
+                             on how regex matching is handled. If False,
+                             no regex matching is done.
+
+        :param kwargs: Specifies values for named fields by which
+                       to constrain the search
         """
-        return self.db.data_source_get_all(context, **kwargs)
+        return self.db.data_source_get_all(context, regex_search, **kwargs)
 
     def data_source_count(self, context, **kwargs):
         """Count Data Sources filtered by **kwargs.
@@ -358,20 +425,62 @@ class ConductorManager(db_base.Base):
 
     def data_source_create(self, context, values):
         """Create a Data Source from the values dictionary."""
+
         values = copy.deepcopy(values)
         values = _apply_defaults(values, DATA_SOURCE_DEFAULTS)
         values['tenant_id'] = context.tenant_id
-
+        # if credentials are being passed in, we use the key_manager
+        # to store the password.
+        if (values.get('credentials') and
+                values['credentials'].get('password')):
+            values['credentials']['password'] = key_manager.store_secret(
+                values['credentials']['password'], context)
         return self.db.data_source_create(context, values)
 
     def data_source_destroy(self, context, data_source):
         """Destroy the Data Source or raise if it does not exist."""
+
+        # in cases where the credentials to access the data source are
+        # stored with the record and the external key manager is being
+        # used, we need to delete the key from the external manager.
+        if (CONF.use_barbican_key_manager and not
+                CONF.use_domain_for_proxy_users):
+            ds_record = self.data_source_get(context, data_source)
+            if (ds_record.get('credentials') and
+                    ds_record['credentials'].get('password')):
+                key_manager.delete_secret(
+                    ds_record['credentials']['password'], context)
         return self.db.data_source_destroy(context, data_source)
 
     def data_source_update(self, context, id, values):
         """Update the Data Source or raise if it does not exist."""
+
         values = copy.deepcopy(values)
         values["id"] = id
+        # in cases where the credentials to access the data source are
+        # stored with the record and the external key manager is being
+        # used, we need to delete the old key from the manager and
+        # create a new one. the other option here would be to retrieve
+        # the previous key and check to see if it has changed, but it
+        # seems less expensive to just delete the old and create a new
+        # one.
+        # it should be noted that the jsonschema validation ensures that
+        # if the proxy domain is not in use then credentials must be
+        # sent with this record.
+        if (CONF.use_barbican_key_manager and not
+                CONF.use_domain_for_proxy_users):
+            # first we retrieve the original record to get the old key
+            # uuid, and delete it.
+            ds_record = self.data_source_get(context, id)
+            if (ds_record.get('credentials') and
+                    ds_record['credentials'].get('password')):
+                key_manager.delete_secret(
+                    ds_record['credentials']['password'], context)
+            # next we create the new key.
+            if (values.get('credentials') and
+                    values['credentials'].get('password')):
+                values['credentials']['password'] = key_manager.store_secret(
+                    values['credentials']['password'], context)
         return self.db.data_source_update(context, values)
 
     # JobExecution ops
@@ -380,7 +489,7 @@ class ConductorManager(db_base.Base):
         """Return the JobExecution or None if it does not exist."""
         return self.db.job_execution_get(context, job_execution)
 
-    def job_execution_get_all(self, context, **kwargs):
+    def job_execution_get_all(self, context, regex_search=False, **kwargs):
         """Get all JobExecutions filtered by **kwargs.
 
         kwargs key values may be the names of fields in a JobExecution
@@ -390,11 +499,18 @@ class ConductorManager(db_base.Base):
         'job.name' -- name of the Job referenced by the JobExecution
         'status' -- JobExecution['info']['status']
 
-        e.g. job_execution_get_all(cluster_id=12, input_id=123)
-             job_execution_get_all(**{'cluster.name': 'test',
-                                      'job.name': 'wordcount'})
+        :param context: The context, and associated authentication, to use with
+                        this operation
+
+        :param regex_search: If True, enable regex matching for filter
+                             values. See the user guide for more information
+                             on how regex matching is handled. If False,
+                             no regex matching is done.
+
+        :param kwargs: Specifies values for named fields by which
+                       to constrain the search
         """
-        return self.db.job_execution_get_all(context, **kwargs)
+        return self.db.job_execution_get_all(context, regex_search, **kwargs)
 
     def job_execution_count(self, context, **kwargs):
         """Count number of JobExecutions filtered by **kwargs.
@@ -425,12 +541,21 @@ class ConductorManager(db_base.Base):
         """Return the Job or None if it does not exist."""
         return self.db.job_get(context, job)
 
-    def job_get_all(self, context, **kwargs):
+    def job_get_all(self, context, regex_search=False, **kwargs):
         """Get all Jobs filtered by **kwargs.
 
-        e.g.  job_get_all(name='myjob', type='MapReduce')
+        :param context: The context, and associated authentication, to use with
+                        this operation
+
+        :param regex_search: If True, enable regex matching for filter
+                             values. See the user guide for more information
+                             on how regex matching is handled. If False,
+                             no regex matching is done.
+
+        :param kwargs: Specifies values for named fields by which
+                       to constrain the search
         """
-        return self.db.job_get_all(context, **kwargs)
+        return self.db.job_get_all(context, regex_search, **kwargs)
 
     def job_create(self, context, values):
         """Create a Job from the values dictionary."""
@@ -449,12 +574,24 @@ class ConductorManager(db_base.Base):
 
     # JobBinary ops
 
-    def job_binary_get_all(self, context, **kwargs):
+    def job_binary_get_all(self, context, regex_search=False, **kwargs):
         """Get all JobBinarys filtered by **kwargs.
 
+        :param context: The context, and associated authentication, to use with
+                        this operation
+
+        :param regex_search: If True, enable regex matching for filter
+                             values. See the user guide for more information
+                             on how regex matching is handled. If False,
+                             no regex matching is done.
+
+        :param kwargs: Specifies values for named fields by which
+                       to constrain the search
+
         e.g.  job_binary_get_all(name='wordcount.jar')
         """
-        return self.db.job_binary_get_all(context, **kwargs)
+        return self.db.job_binary_get_all(context,
+                                          regex_search, **kwargs)
 
     def job_binary_get(self, context, job_binary_id):
         """Return the JobBinary or None if it does not exist."""
@@ -466,10 +603,25 @@ class ConductorManager(db_base.Base):
         values = copy.deepcopy(values)
         values = _apply_defaults(values, JOB_BINARY_DEFAULTS)
         values['tenant_id'] = context.tenant_id
+        # if credentials are being passed in, we use the key_manager
+        # to store the password.
+        if values.get('extra') and values['extra'].get('password'):
+            values['extra']['password'] = key_manager.store_secret(
+                values['extra']['password'], context)
         return self.db.job_binary_create(context, values)
 
     def job_binary_destroy(self, context, job_binary):
         """Destroy the JobBinary or raise if it does not exist."""
+
+        # in cases where the credentials to access the job binary are
+        # stored with the record and the external key manager is being
+        # used, we need to delete the key from the external manager.
+        if (CONF.use_barbican_key_manager and not
+                CONF.use_domain_for_proxy_users):
+            jb_record = self.job_binary_get(context, job_binary)
+            if jb_record.get('extra') and jb_record['extra'].get('password'):
+                key_manager.delete_secret(jb_record['extra']['password'],
+                                          context)
         self.db.job_binary_destroy(context, job_binary)
 
     def job_binary_update(self, context, id, values):
@@ -477,18 +629,48 @@ class ConductorManager(db_base.Base):
 
         values = copy.deepcopy(values)
         values['id'] = id
+        # in cases where the credentials to access the job binary are
+        # stored with the record and the external key manager is being
+        # used, we need to delete the old key from the manager and
+        # create a new one. the other option here would be to retrieve
+        # the previous key and check to see if it has changed, but it
+        # seems less expensive to just delete the old and create a new
+        # one.
+        if (CONF.use_barbican_key_manager and not
+                CONF.use_domain_for_proxy_users):
+            # first we retrieve the original record to get the old key
+            # uuid, and delete it.
+            jb_record = self.job_binary_get(context, id)
+            if jb_record.get('extra') and jb_record['extra'].get('password'):
+                key_manager.delete_secret(jb_record['extra']['password'],
+                                          context)
+            # next we create the new key.
+            if values.get('extra') and values['extra'].get('password'):
+                values['extra']['password'] = key_manager.store_secret(
+                    values['extra']['password'], context)
         return self.db.job_binary_update(context, values)
 
     # JobBinaryInternal ops
 
-    def job_binary_internal_get_all(self, context, **kwargs):
+    def job_binary_internal_get_all(self, context,
+                                    regex_search=False, **kwargs):
         """Get all JobBinaryInternals filtered by **kwargs.
 
-        e.g.  cluster_get_all(name='wordcount.jar')
-
         The JobBinaryInternals returned do not contain a data field.
+
+        :param context: The context, and associated authentication, to use with
+                        this operation
+
+        :param regex_search: If True, enable regex matching for filter
+                             values. See the user guide for more information
+                             on how regex matching is handled. If False,
+                             no regex matching is done.
+
+        :param kwargs: Specifies values for named fields by which
+                       to constrain the search
         """
-        return self.db.job_binary_internal_get_all(context, **kwargs)
+        return self.db.job_binary_internal_get_all(context,
+                                                   regex_search, **kwargs)
 
     def job_binary_internal_get(self, context, job_binary_internal_id):
         """Return the JobBinaryInternal or None if it does not exist
@@ -540,3 +722,36 @@ class ConductorManager(db_base.Base):
     def cluster_event_add(self, context, provision_step, values):
         """Assign new event to the specified provision step."""
         return self.db.cluster_event_add(context, provision_step, values)
+
+    # Cluster verifications / health checks ops
+
+    def cluster_verification_add(self, context, cluster_id, values):
+        """Return created verification for the specified cluster."""
+        return self.db.cluster_verification_add(context, cluster_id, values)
+
+    def cluster_verification_get(self, context, verification_id):
+        """Return verification with the specified verification_id."""
+        return self.db.cluster_verification_get(context, verification_id)
+
+    def cluster_verification_update(self, context, verification_id, values):
+        """Return updated verification with the specified verification_id."""
+        return self.db.cluster_verification_update(
+            context, verification_id, values)
+
+    def cluster_verification_delete(self, context, verification_id):
+        """"Delete verification with the specified id."""
+        return self.db.cluster_verification_delete(context, verification_id)
+
+    def cluster_health_check_add(self, context, verification_id, values):
+        """Return created health check in the specified verification."""
+        return self.db.cluster_health_check_add(
+            context, verification_id, values)
+
+    def cluster_health_check_get(self, context, health_check_id):
+        """Return health check with the specified health_check_id."""
+        return self.db.cluster_health_check_get(context, health_check_id)
+
+    def cluster_health_check_update(self, context, health_check_id, values):
+        """Return updated health check with the specified health_check_id."""
+        return self.db.cluster_health_check_update(
+            context, health_check_id, values)
