@@ -15,13 +15,15 @@
 
 import itertools
 
+# loading keystonemiddleware opts because sahara uses these options in code
+from keystonemiddleware import opts  # noqa
 from oslo_config import cfg
-from oslo_config import types
 from oslo_log import log
 
 from sahara import exceptions as ex
 from sahara.i18n import _
 from sahara.plugins import base as plugins_base
+from sahara.service.castellan import config as castellan
 from sahara.topology import topology_helper
 from sahara.utils.notification import sender
 from sahara.utils.openstack import cinder
@@ -29,14 +31,12 @@ from sahara.utils.openstack import keystone
 from sahara.utils import remote
 from sahara import version
 
-PORT_TYPE = types.Integer(1, 65535)
-
 
 cli_opts = [
     cfg.StrOpt('host', default='',
                help='Hostname or IP address that will be used to listen on.'),
-    cfg.Opt('port', default=8386, type=PORT_TYPE,
-            help='Port that will be used to listen on.'),
+    cfg.PortOpt('port', default=8386,
+                help='Port that will be used to listen on.'),
     cfg.BoolOpt('log-exchange', default=False,
                 help='Log request/response exchange details: environ, '
                      'headers and bodies.')
@@ -128,8 +128,10 @@ def list_opts():
 
     from sahara.conductor import api
     from sahara import main as sahara_main
+    from sahara.service import coordinator
     from sahara.service.edp import job_utils
     from sahara.service.heat import heat_engine
+    from sahara.service.heat import templates
     from sahara.service import periodic
     from sahara.swift import swift_helper
     from sahara.utils import cluster_progress_ops as cpo
@@ -140,7 +142,7 @@ def list_opts():
     from sahara.utils.openstack import swift
     from sahara.utils import poll_utils
     from sahara.utils import proxy
-    from sahara.utils import wsgi
+    from sahara.utils import ssh_remote
 
     return [
         (None,
@@ -150,17 +152,19 @@ def list_opts():
                          db_opts,
                          plugins_base.opts,
                          topology_helper.opts,
-                         sender.notifier_opts,
                          keystone.opts,
                          remote.ssh_opts,
                          sahara_main.opts,
                          job_utils.opts,
                          periodic.periodic_opts,
+                         coordinator.coordinator_opts,
                          proxy.opts,
                          cpo.event_log_opts,
-                         wsgi.wsgi_opts,
                          base.opts,
-                         heat_engine.heat_engine_opts)),
+                         heat_engine.heat_engine_opts,
+                         templates.heat_engine_opts,
+                         ssh_remote.ssh_config_options,
+                         castellan.opts)),
         (poll_utils.timeouts.name,
          itertools.chain(poll_utils.timeouts_opts)),
         (api.conductor_group.name,
@@ -180,7 +184,10 @@ def list_opts():
         (base.retries.name,
          itertools.chain(base.opts)),
         (swift_helper.public_endpoint_cert_group.name,
-         itertools.chain(swift_helper.opts))
+         itertools.chain(swift_helper.opts)),
+        (castellan.castellan_group.name,
+         itertools.chain(castellan.castellan_opts)),
+        (sender.notifier_opts_group, sender.notifier_opts)
     ]
 
 
