@@ -33,7 +33,7 @@ class SaharaException(Exception):
     def __str__(self):
         return self.message
 
-    def __init__(self, message=None, code=None):
+    def __init__(self, message=None, code=None, inject_error_id=True):
         self.uuid = uuidutils.generate_uuid()
 
         if code:
@@ -41,9 +41,10 @@ class SaharaException(Exception):
         if message:
             self.message = message
 
-        # Add Error UUID to the message
-        self.message = (_('%(message)s\nError ID: %(id)s')
-                        % {'message': self.message, 'id': self.uuid})
+        if inject_error_id:
+            # Add Error UUID to the message if required
+            self.message = (_('%(message)s\nError ID: %(id)s')
+                            % {'message': self.message, 'id': self.uuid})
 
         super(SaharaException, self).__init__(
             '%s: %s' % (self.code, self.message))
@@ -147,6 +148,16 @@ class CancelingFailed(SaharaException):
     code = "CANCELING_FAILED"
 
 
+class SuspendingFailed(SaharaException):
+    message = _("Operation was not suspended")
+    code = "SUSPENDING_FAILED"
+
+
+class InvalidJobStatus(SaharaException):
+    message = _("Invalid Job Status")
+    code = "INVALID_JOB_STATUS"
+
+
 class DeletionFailed(SaharaException):
     code = "DELETION_FAILED"
     message = _("Object was not deleted")
@@ -173,7 +184,7 @@ class SwiftClientException(SaharaException):
     '''
 
     code = "SWIFT_CLIENT_EXCEPTION"
-    message = _("An error has occured while performing a request to Swift")
+    message = _("An error has occurred while performing a request to Swift")
 
 
 class DataTooBigException(SaharaException):
@@ -224,9 +235,13 @@ class HeatStackException(SaharaException):
     code = "HEAT_STACK_EXCEPTION"
     message_template = _("Heat stack failed with status %s")
 
-    def __init__(self, heat_stack_status):
-        formatted_message = self.message_template % heat_stack_status
-
+    def __init__(self, heat_stack_status=None, message=None):
+        if message:
+            formatted_message = message
+        elif heat_stack_status:
+            formatted_message = self.message_template % heat_stack_status
+        else:
+            formatted_message = _("Heat stack failed")
         super(HeatStackException, self).__init__(formatted_message)
 
 
@@ -252,7 +267,7 @@ class FrozenClassError(SaharaException):
 
 class SystemError(SaharaException):
     code = "SYSTEM_ERROR"
-    message = _("System error has occured")
+    message = _("System error has occurred")
 
 
 class EDPError(SaharaException):
@@ -354,3 +369,13 @@ class MaxRetriesExceeded(SaharaException):
                                                      'attempts': attempts}
 
         super(MaxRetriesExceeded, self).__init__(formatted_message)
+
+
+class InvalidJobExecutionInfoException(SaharaException):
+    message = _("Job execution information is invalid")
+
+    def __init__(self, message=None):
+        if message:
+            self.message = message
+        self.code = "INVALID_JOB_EXECUTION_INFO"
+        super(InvalidJobExecutionInfoException, self).__init__()
