@@ -17,6 +17,7 @@
 from oslo_serialization import jsonutils
 import six
 
+from sahara.i18n import _
 from sahara.plugins.ambari import common
 from sahara.plugins import provisioning
 from sahara.plugins import utils
@@ -79,6 +80,22 @@ CFG_PROCESS_MAP = {
 }
 
 
+SERVICES_TO_CONFIGS_MAP = None
+
+
+def get_service_to_configs_map():
+    global SERVICES_TO_CONFIGS_MAP
+    if SERVICES_TO_CONFIGS_MAP:
+        return SERVICES_TO_CONFIGS_MAP
+    data = {}
+    for (key, item) in six.iteritems(CFG_PROCESS_MAP):
+        if item not in data:
+            data[item] = []
+        data[item].append(key)
+    SERVICES_TO_CONFIGS_MAP = data
+    return SERVICES_TO_CONFIGS_MAP
+
+
 ng_confs = [
     "dfs.datanode.data.dir",
     "dtnode_heapsize",
@@ -97,6 +114,9 @@ ng_confs = [
 ]
 
 
+use_base_repos_cfg = provisioning.Config(
+    "Enable external repos on instances", 'general', 'cluster', priority=1,
+    default_value=True, config_type="bool")
 hdp_repo_cfg = provisioning.Config(
     "HDP repo URL", "general", "cluster", priority=1, default_value="")
 hdp_utils_repo_cfg = provisioning.Config(
@@ -122,18 +142,56 @@ def _get_param_scope(param):
         return "cluster"
 
 
+def _get_ha_params():
+    enable_namenode_ha = provisioning.Config(
+        name=common.NAMENODE_HA,
+        applicable_target="general",
+        scope="cluster",
+        config_type="bool",
+        default_value=False,
+        is_optional=True,
+        description=_("Enable NameNode HA"),
+        priority=1)
+
+    enable_resourcemanager_ha = provisioning.Config(
+        name=common.RESOURCEMANAGER_HA,
+        applicable_target="general",
+        scope="cluster",
+        config_type="bool",
+        default_value=False,
+        is_optional=True,
+        description=_("Enable ResourceManager HA"),
+        priority=1)
+
+    enable_regionserver_ha = provisioning.Config(
+        name=common.HBASE_REGIONSERVER_HA,
+        applicable_target="general",
+        scope="cluster",
+        config_type="bool",
+        default_value=False,
+        is_optional=True,
+        description=_("Enable HBase RegionServer HA"),
+        priority=1)
+
+    return [enable_namenode_ha,
+            enable_resourcemanager_ha,
+            enable_regionserver_ha]
+
+
 def load_configs(version):
     if OBJ_CONFIGS.get(version):
         return OBJ_CONFIGS[version]
     cfg_path = "plugins/ambari/resources/configs-%s.json" % version
     vanilla_cfg = jsonutils.loads(files.get_file_text(cfg_path))
     CONFIGS[version] = vanilla_cfg
-    sahara_cfg = [hdp_repo_cfg, hdp_utils_repo_cfg]
+    sahara_cfg = [hdp_repo_cfg, hdp_utils_repo_cfg, use_base_repos_cfg]
     for service, confs in vanilla_cfg.items():
         for k, v in confs.items():
             sahara_cfg.append(provisioning.Config(
                 k, _get_service_name(service), _get_param_scope(k),
                 default_value=v))
+
+    sahara_cfg.extend(_get_ha_params())
     OBJ_CONFIGS[version] = sahara_cfg
     return sahara_cfg
 
@@ -143,6 +201,10 @@ def _get_config_value(cluster, key):
                                                           key.default_value)
 
 
+def use_base_repos_needed(cluster):
+    return _get_config_value(cluster, use_base_repos_cfg)
+
+
 def get_hdp_repo_url(cluster):
     return _get_config_value(cluster, hdp_repo_cfg)
 
@@ -158,6 +220,9 @@ def _serialize_ambari_configs(configs):
 def _create_ambari_configs(sahara_configs, plugin_version):
     configs = {}
     for service, params in six.iteritems(sahara_configs):
+        if service == "general":
+            # General configs are designed for Sahara, not for the plugin
+            continue
         for k, v in six.iteritems(params):
             group = _get_config_group(service, k, plugin_version)
             configs.setdefault(group, {})
@@ -169,7 +234,7 @@ def _make_paths(dirs, suffix):
     return ",".join([d + suffix for d in dirs])
 
 
-def get_instance_params(inst):
+def get_instance_params_mapping(inst):
     configs = _create_ambari_configs(inst.node_group.node_configs,
                                      inst.node_group.cluster.hadoop_version)
     storage_paths = inst.storage_paths()
@@ -190,7 +255,14 @@ def get_instance_params(inst):
     configs["yarn-site"][
         "yarn.timeline-service.leveldb-timeline-store.path"] = _make_paths(
             storage_paths, "/yarn/timeline")
-    return _serialize_ambari_configs(configs)
+    configs.setdefault("oozie-site", {})
+    configs["oozie-site"][
+        "oozie.service.AuthorizationService.security.enabled"] = "false"
+    return configs
+
+
+def get_instance_params(inst):
+    return _serialize_ambari_configs(get_instance_params_mapping(inst))
 
 
 def get_cluster_params(cluster):
@@ -205,3 +277,37 @@ def get_cluster_params(cluster):
         configs["admin-properties"]["db_root_password"] = (
             cluster.extra["ranger_db_password"])
     return _serialize_ambari_configs(configs)
+
+
+def get_config_group(instance):
+    params = get_instance_params_mapping(instance)
+    groups = []
+    for (service, targets) in six.iteritems(get_service_to_configs_map()):
+        current_group = {
+            'cluster_name': instance.cluster.name,
+            'group_name': "%s:%s" % (
+                instance.cluster.name, instance.instance_name),
+            'tag': service,
+            'description': "Config group for scaled "
+                           "node %s" % instance.instance_name,
+            'hosts': [
+                {
+                    'host_name': instance.fqdn()
+                }
+            ],
+            'desired_configs': []
+        }
+        at_least_one_added = False
+        for target in targets:
+            configs = params.get(target, {})
+            if configs:
+                current_group['desired_configs'].append({
+                    'type': target,
+                    'properties': configs,
+                    'tag': instance.instance_name
+                })
+                at_least_one_added = True
+        if at_least_one_added:
+            # Config Group without overridden data is not interesting
+            groups.append({'ConfigGroup': current_group})
+    return groups
