@@ -71,7 +71,7 @@ class CDHPluginProvider(p.ProvisioningPluginBase):
         return self._get_version_handler(
             cluster.hadoop_version).get_edp_engine(cluster, job_type)
 
-    def get_edp_job_types(self, versions=[]):
+    def get_edp_job_types(self, versions=None):
         res = {}
         for vers in self.version_factory.get_versions():
             if not versions or vers in versions:
@@ -91,3 +91,7 @@ class CDHPluginProvider(p.ProvisioningPluginBase):
     def recommend_configs(self, cluster, scaling=False):
         return self._get_version_handler(
             cluster.hadoop_version).recommend_configs(cluster, scaling)
+
+    def get_health_checks(self, cluster):
+        return self._get_version_handler(
+            cluster.hadoop_version).get_health_checks(cluster)
