@@ -1,4 +1,4 @@
-# Copyright (c) 2014 Intel Corporation.
+# Copyright (c) 2015 Intel Corporation
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,15 +14,17 @@
 # limitations under the License.
 
 from sahara.conductor import resource as res
+from sahara.plugins.cdh import commands as cmd
 from sahara.plugins.cdh import plugin_utils as pu
-from sahara.plugins.cdh.v5_3_0 import config_helper as c_helper
-from sahara.plugins.cdh.v5_3_0 import db_helper
+from sahara.plugins.cdh.v5_5_0 import config_helper
+from sahara.plugins.cdh.v5_5_0 import db_helper
 from sahara.plugins import utils as u
 
 
-class PluginUtilsV530(pu.AbstractPluginUtils):
+class PluginUtilsV550(pu.AbstractPluginUtils):
+
     def __init__(self):
-        self.c_helper = c_helper
+        self.c_helper = config_helper.ConfigHelperV550()
         self.db_helper = db_helper
 
     def get_role_name(self, instance, service):
@@ -39,6 +41,8 @@ class PluginUtilsV530(pu.AbstractPluginUtils):
             'HOSTMONITOR': 'HM',
             'IMPALAD': 'ID',
             'JOBHISTORY': 'JS',
+            'JOURNALNODE': 'JN',
+            'KMS': 'KMS',
             'MASTER': 'M',
             'NAMENODE': 'NN',
             'NODEMANAGER': 'NM',
@@ -84,6 +88,15 @@ class PluginUtilsV530(pu.AbstractPluginUtils):
     def get_impalads(self, cluster):
         return u.get_instances(cluster, 'IMPALAD')
 
+    def get_kms(self, cluster):
+        return u.get_instances(cluster, 'KMS')
+
+    def get_jns(self, cluster):
+        return u.get_instances(cluster, 'HDFS_JOURNALNODE')
+
+    def get_stdb_rm(self, cluster):
+        return u.get_instance(cluster, 'YARN_STANDBYRM')
+
     def convert_process_configs(self, configs):
         p_dict = {
             "CLOUDERA": ['MANAGER'],
@@ -110,8 +123,10 @@ class PluginUtilsV530(pu.AbstractPluginUtils):
             "SENTRY": ['SENTRY_SERVER'],
             "SOLR": ['SOLR_SERVER'],
             "SQOOP": ['SQOOP_SERVER'],
+            "KMS": ['KMS'],
             'YARN_GATEWAY': ['YARN_GATEWAY'],
-            'HDFS_GATEWAY': ['HDFS_GATEWAY']
+            'HDFS_GATEWAY': ['HDFS_GATEWAY'],
+            "JOURNALNODE": ['JOURNALNODE']
         }
         if isinstance(configs, res.Resource):
             configs = configs.to_dict()
@@ -128,10 +143,20 @@ class PluginUtilsV530(pu.AbstractPluginUtils):
         with manager.remote() as r:
             self.db_helper.create_sentry_database(cluster, r)
 
-    def start_cloudera_manager(self, cluster):
-        self._start_cloudera_manager(
-            cluster, c_helper.AWAIT_MANAGER_STARTING_TIMEOUT)
+    def _configure_repo_from_inst(self, instance):
+        super(PluginUtilsV550, self)._configure_repo_from_inst(instance)
 
-    def get_config_value(self, service, name, cluster=None):
-        configs = c_helper.get_plugin_configs()
-        return self._get_config_value(service, name, configs, cluster)
+        cluster = instance.cluster
+        with instance.remote() as r:
+            if cmd.is_ubuntu_os(r):
+                kms_key = (
+                    self.c_helper.get_kms_key_url(cluster) or
+                    self.c_helper.DEFAULT_KEY_TRUSTEE_UBUNTU_REPO_KEY_URL)
+                kms_repo_url = self.c_helper.KEY_TRUSTEE_UBUNTU_REPO_URL
+                cmd.add_ubuntu_repository(r, kms_repo_url, 'kms')
+                cmd.add_apt_key(r, kms_key)
+                cmd.update_repository(r)
+            if cmd.is_centos_os(r):
+                kms_repo_url = self.c_helper.KEY_TRUSTEE_CENTOS_REPO_URL
+                cmd.add_centos_repository(r, kms_repo_url, 'kms')
+                cmd.update_repository(r)
