@@ -18,6 +18,7 @@ from oslo_log import log as logging
 
 from sahara import conductor as c
 from sahara import context
+from sahara import exceptions as base_exc
 from sahara.i18n import _
 from sahara.i18n import _LI
 from sahara.plugins import exceptions as ex
@@ -296,12 +297,10 @@ class AmbariPlugin(p.ProvisioningPluginBase):
                  'of the Hortonworks Data Platform (HDP) on OpenStack.')
 
     def validate(self, cluster):
-        # creating operational config results in validation
-        handler = self.version_factory.get_version_handler(
-            cluster.hadoop_version)
-
-        handler.get_cluster_spec(cluster, self._map_to_user_inputs(
-            cluster.hadoop_version, cluster.cluster_configs))
+        raise base_exc.DeprecatedException(
+            _("The HDP 2.0.6 plugin is deprecated in Mitaka release and "
+              "will be removed in Newton release. Please, use the Ambari 2.3 "
+              "instead."))
 
     def scale_cluster(self, cluster, instances):
         handler = self.version_factory.get_version_handler(
@@ -349,7 +348,7 @@ class AmbariPlugin(p.ProvisioningPluginBase):
             self.version_factory.get_version_handler(cluster.hadoop_version))
         return version_handler.get_edp_engine(cluster, job_type)
 
-    def get_edp_job_types(self, versions=[]):
+    def get_edp_job_types(self, versions=None):
         res = {}
         for vers in self.version_factory.get_versions():
             if not versions or vers in versions:
@@ -385,7 +384,8 @@ class AmbariPlugin(p.ProvisioningPluginBase):
 
         # results in validation
         handler.get_cluster_spec(
-            cluster, [], dict(existing.items() + additional.items()))
+            cluster, [],
+            dict(list(existing.items()) + list(additional.items())))
 
     def _get_num_hosts(self, cluster):
         count = 0
