@@ -14,7 +14,6 @@
 
 
 from oslo_log import log as logging
-import six
 
 import sahara.plugins.mapr.domain.configuration_file as bcf
 import sahara.plugins.mapr.domain.node_process as np
@@ -39,9 +38,6 @@ HIVE_SERVER_2 = np.NodeProcess(
 
 
 class Hive(s.Service):
-    SCHEMA_PATH_TEMPLATE = ("%(hive_home)s/scripts/metastore/upgrade/mysql/"
-                            "hive-schema-%(hive_version)s.0.mysql.sql")
-
     def __init__(self):
         super(Hive, self).__init__()
         self._name = 'hive'
@@ -61,8 +57,15 @@ class Hive(s.Service):
             hive_site.fetch(instance)
         hive_site.parse(files.get_file_text(hive_default))
         hive_site.add_properties(self._get_hive_site_props(cluster_context))
+        hue_version = cluster_context.get_chosen_service_version('Hue')
+        if self.require_no_sasl(hue_version):
+            hive_site.add_property('hive.server2.authentication', 'NOSASL')
+
         return [hive_site]
 
+    def require_no_sasl(self, version):
+        return version not in ['3.9.0']
+
     def _get_hive_site_props(self, context):
         # Import here to resolve circular dependency
         from sahara.plugins.mapr.services.mysql import mysql
@@ -113,15 +116,7 @@ class Hive(s.Service):
             LOG.debug("Creating Hive warehouse dir")
             r.execute_command(cmd % args, raise_when_error=False)
 
-    def get_schema_path(self, cluster_context):
-        args = {
-            "hive_home": self.home_dir(cluster_context),
-            "hive_version": self.version,
-        }
-        return self.SCHEMA_PATH_TEMPLATE % args
 
-
-@six.add_metaclass(s.Single)
 class HiveV013(Hive):
     def __init__(self):
         super(HiveV013, self).__init__()
@@ -129,17 +124,15 @@ class HiveV013(Hive):
         self._dependencies = [('mapr-hive', self.version)]
 
 
-@six.add_metaclass(s.Single)
 class HiveV10(Hive):
     def __init__(self):
         super(HiveV10, self).__init__()
         self._version = "1.0"
         self._dependencies = [("mapr-hive", self.version)]
 
-    def get_schema_path(self, cluster_context):
-        args = {
-            "hive_home": self.home_dir(cluster_context),
-            # Hive 1.0 uses schema for Hive 0.14
-            "hive_version": "0.14",
-        }
-        return self.SCHEMA_PATH_TEMPLATE % args
+
+class HiveV12(Hive):
+    def __init__(self):
+        super(HiveV12, self).__init__()
+        self._version = "1.2"
+        self._dependencies = [("mapr-hive", self.version)]
