@@ -12,10 +12,9 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-
 from oslo_log import log as logging
-import six
 
+import sahara.context as con
 import sahara.plugins.mapr.domain.configuration_file as bcf
 import sahara.plugins.mapr.domain.node_process as np
 import sahara.plugins.mapr.domain.service as s
@@ -23,8 +22,10 @@ import sahara.plugins.mapr.services.mysql.mysql as mysql
 import sahara.plugins.mapr.util.general as g
 import sahara.plugins.mapr.util.validation_utils as vu
 
+
 LOG = logging.getLogger(__name__)
-OOZIE_LIBEXT_TEMPLATE = '/opt/mapr/oozie/oozie-%s/oozie-server/lib/'
+OOZIE_START_DELAY = 30
+
 OOZIE = np.NodeProcess(
     name='oozie',
     ui_name='Oozie',
@@ -33,7 +34,6 @@ OOZIE = np.NodeProcess(
 )
 
 
-@six.add_metaclass(s.Single)
 class Oozie(s.Service):
     def __init__(self):
         super(Oozie, self).__init__()
@@ -45,10 +45,9 @@ class Oozie(s.Service):
         self._ui_info = [('Oozie', OOZIE, 'http://%s:11000/oozie')]
 
     def libext_path(self):
-        return OOZIE_LIBEXT_TEMPLATE % self.version
+        return '/opt/mapr/oozie/oozie-%s/oozie-server/lib/' % self.version
 
     def get_config_files(self, cluster_context, configs, instance=None):
-        super(Oozie, self).install(cluster_context, [instance])
         oozie_site = bcf.HadoopXML("oozie-site.xml")
         oozie_site.remote_path = self.conf_dir(cluster_context)
         if instance:
@@ -105,8 +104,8 @@ class Oozie(s.Service):
 
     @g.remote_command(1)
     def _rebuild_oozie_war(self, remote, cluster_context):
-        cmd = ('%(home)s/bin/oozie-setup.sh -hadoop %(version)s '
-               '/opt/mapr/hadoop/hadoop-%(version)s')
+        cmd = '%(home)s/bin/oozie-setup.sh -hadoop %(version)s' \
+              ' /opt/mapr/hadoop/hadoop-%(version)s'
         args = {'home': self.home_dir(cluster_context),
                 'version': cluster_context.hadoop_version}
         remote.execute_command(cmd % args, run_as_root=True)
@@ -121,9 +120,9 @@ class Oozie(s.Service):
         g.execute_on_instances(
             instances, self._rebuild_oozie_war, cluster_context)
         OOZIE.start(instances)
+        con.sleep(OOZIE_START_DELAY)
 
 
-@six.add_metaclass(s.Single)
 class OozieV401(Oozie):
     def __init__(self):
         super(OozieV401, self).__init__()
@@ -131,9 +130,42 @@ class OozieV401(Oozie):
         self._dependencies = [('mapr-oozie-internal', self.version)]
 
 
-@six.add_metaclass(s.Single)
 class OozieV410(Oozie):
     def __init__(self):
         super(OozieV410, self).__init__()
         self._version = '4.1.0'
         self._dependencies = [('mapr-oozie-internal', self.version)]
+
+
+class OozieV420(Oozie):
+    def __init__(self):
+        super(OozieV420, self).__init__()
+        self._version = '4.2.0'
+        self._dependencies = [('mapr-oozie-internal', self.version)]
+
+    def libext_path(self):
+        return '/opt/mapr/oozie/oozie-%s/libext/' % self.version
+
+    def post_install(self, cluster_context, instances):
+        super(OozieV420, self).post_install(cluster_context, instances)
+        self.fix_oozie_bug(cluster_context)
+
+    def fix_oozie_bug(self, cluster_context):
+        """Wrong maprfs jar bug
+
+        On some environments Oozie installation
+        process takes incorrect jar that causes failure
+        to run jobs. This is a temporary bug in Oozie and
+        is going to be fixed soon.
+        """
+
+        if cluster_context.mapr_version != '5.1.0':
+            return
+        oozie_inst = cluster_context.get_instance(OOZIE)
+        command = "sudo rm /opt/mapr/hadoop/hadoop-2.7.0/share/hadoop/kms/" \
+                  "tomcat/webapps/kms/WEB-INF/lib/maprfs-5.1.0-mapr.jar" \
+                  " && sudo ln -s /opt/mapr/lib/maprfs-5.1.0-mapr.jar" \
+                  " /opt/mapr/hadoop/hadoop-2.7.0/share/hadoop/kms/" \
+                  "tomcat/webapps/kms/WEB-INF/lib/maprfs-5.1.0-mapr.jar"
+        with oozie_inst.remote() as r:
+            r.execute_command(command, run_as_root=True)
