@@ -1,4 +1,4 @@
-# Copyright (c) 2014 Mirantis Inc.
+# Copyright (c) 2015 Mirantis Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,19 +18,18 @@ from oslo_log import log as logging
 
 from sahara import conductor
 from sahara import context
-from sahara import exceptions as ex
-from sahara.i18n import _
 from sahara.plugins import utils
 from sahara.plugins.vanilla import abstractversionhandler as avm
 from sahara.plugins.vanilla.hadoop2 import config as c
+from sahara.plugins.vanilla.hadoop2 import keypairs
 from sahara.plugins.vanilla.hadoop2 import recommendations_utils as ru
 from sahara.plugins.vanilla.hadoop2 import run_scripts as run
 from sahara.plugins.vanilla.hadoop2 import scaling as sc
 from sahara.plugins.vanilla.hadoop2 import starting_scripts as s_scripts
 from sahara.plugins.vanilla.hadoop2 import validation as vl
 from sahara.plugins.vanilla import utils as vu
-from sahara.plugins.vanilla.v2_6_0 import config_helper as c_helper
-from sahara.plugins.vanilla.v2_6_0 import edp_engine
+from sahara.plugins.vanilla.v2_7_1 import config_helper as c_helper
+from sahara.plugins.vanilla.v2_7_1 import edp_engine
 from sahara.swift import swift_helper
 from sahara.utils import cluster as cluster_utils
 
@@ -61,10 +60,7 @@ class VersionHandler(avm.AbstractVersionHandler):
         }
 
     def validate(self, cluster):
-        raise ex.DeprecatedException(
-            _("The vanilla 2.6.0 plugin is now deprecated and will be removed"
-              " in M release. The vanilla 2.7.1 plugin remains and "
-              " continues to be supported."))
+        vl.validate_cluster_creating(self.pctx, cluster)
 
     def update_infra(self, cluster):
         pass
@@ -73,6 +69,8 @@ class VersionHandler(avm.AbstractVersionHandler):
         c.configure_cluster(self.pctx, cluster)
 
     def start_cluster(self, cluster):
+        keypairs.provision_keypairs(cluster)
+
         s_scripts.start_namenode(cluster)
         s_scripts.start_secondarynamenode(cluster)
         s_scripts.start_resourcemanager(cluster)
@@ -96,6 +94,7 @@ class VersionHandler(avm.AbstractVersionHandler):
         vl.validate_existing_ng_scaling(self.pctx, cluster, existing)
 
     def scale_cluster(self, cluster, instances):
+        keypairs.provision_keypairs(cluster, instances)
         sc.scale_cluster(self.pctx, cluster, instances)
 
     def _set_cluster_info(self, cluster):
@@ -142,6 +141,9 @@ class VersionHandler(avm.AbstractVersionHandler):
     def get_edp_config_hints(self, job_type):
         return edp_engine.EdpOozieEngine.get_possible_job_config(job_type)
 
+    def on_terminate_cluster(self, cluster):
+        keypairs.drop_key(cluster)
+
     def get_open_ports(self, node_group):
         return c.get_open_ports(node_group)
 
