@@ -50,7 +50,7 @@ def _get_job_type(job_execution):
     return conductor.job_get(context.ctx(), job_execution.job_id).type
 
 
-def _get_job_engine(cluster, job_execution):
+def get_job_engine(cluster, job_execution):
     return job_utils.get_plugin(cluster).get_edp_engine(cluster,
                                                         _get_job_type(
                                                             job_execution))
@@ -91,10 +91,12 @@ def _run_job(job_execution_id):
     ctx = context.ctx()
     job_execution = conductor.job_execution_get(ctx, job_execution_id)
     cluster = conductor.cluster_get(ctx, job_execution.cluster_id)
-    if cluster.status != c_u.CLUSTER_STATUS_ACTIVE:
+    if cluster is None or cluster.status != c_u.CLUSTER_STATUS_ACTIVE:
+        LOG.info(_LI("Can not run this job on a non-existant cluster or a"
+                     " inactive cluster."))
         return
 
-    eng = _get_job_engine(cluster, job_execution)
+    eng = get_job_engine(cluster, job_execution)
     if eng is None:
         raise e.EDPError(_("Cluster does not support job type %s")
                          % _get_job_type(job_execution))
@@ -103,7 +105,11 @@ def _run_job(job_execution_id):
     # Job id is a string
     # Status is a string
     # Extra is a dictionary to add to extra in the job_execution
-    jid, status, extra = eng.run_job(job_execution)
+    if job_execution.job_configs.job_execution_info.get('job_execution_type'
+                                                        ) == 'scheduled':
+        jid, status, extra = eng.run_scheduled_job(job_execution)
+    else:
+        jid, status, extra = eng.run_job(job_execution)
 
     # Set the job id and the start time
     # Optionally, update the status and the 'extra' field
@@ -113,6 +119,8 @@ def _run_job(job_execution_id):
         update_dict['info'] = {'status': status}
     if extra:
         curr_extra = job_execution.extra.copy()
+        if 'neutron' in curr_extra:
+            curr_extra['neutron'] = curr_extra['neutron'].copy()
         curr_extra.update(extra)
         update_dict['extra'] = curr_extra
 
@@ -145,11 +153,14 @@ def cancel_job(job_execution_id):
     ctx = context.ctx()
     job_execution = conductor.job_execution_get(ctx, job_execution_id)
     if job_execution.info['status'] in edp.JOB_STATUSES_TERMINATED:
+        LOG.info(_LI("Job execution is already finished and shouldn't be"
+                     " canceled"))
         return job_execution
     cluster = conductor.cluster_get(ctx, job_execution.cluster_id)
     if cluster is None:
+        LOG.info(_LI("Can not cancel this job on a non-existant cluster."))
         return job_execution
-    engine = _get_job_engine(cluster, job_execution)
+    engine = get_job_engine(cluster, job_execution)
     if engine is not None:
         job_execution = conductor.job_execution_update(
             ctx, job_execution_id,
@@ -192,27 +203,64 @@ def get_job_status(job_execution_id):
     cluster = conductor.cluster_get(ctx, job_execution.cluster_id)
     if (cluster is not None and
             cluster.status == c_u.CLUSTER_STATUS_ACTIVE):
-        engine = _get_job_engine(cluster, job_execution)
+        engine = get_job_engine(cluster, job_execution)
         if engine is not None:
             job_execution = _update_job_status(engine,
                                                job_execution)
     return job_execution
 
 
+def update_job_status(job_execution_id):
+    try:
+        get_job_status(job_execution_id)
+    except Exception as e:
+        LOG.error(_LE("Error during update job execution {job}: {error}")
+                  .format(job=job_execution_id, error=e))
+
+
 def update_job_statuses(cluster_id=None):
     ctx = context.ctx()
     kwargs = {'end_time': None}
     if cluster_id:
         kwargs.update({'cluster_id': cluster_id})
     for je in conductor.job_execution_get_all(ctx, **kwargs):
-        try:
-            get_job_status(je.id)
-        except Exception as e:
-            LOG.error(_LE("Error during update job execution {job}: {error}")
-                      .format(job=je.id, error=e))
+        update_job_status(je.id)
 
 
 def get_job_config_hints(job_type):
     for eng in ENGINES:
         if job_type in eng.get_supported_job_types():
             return eng.get_possible_job_config(job_type)
+
+
+def suspend_job(job_execution_id):
+    ctx = context.ctx()
+    job_execution = conductor.job_execution_get(ctx, job_execution_id)
+    if job_execution.info['status'] not in edp.JOB_STATUSES_SUSPENDIBLE:
+        raise e.SuspendingFailed(_("Suspending operation can not be performed"
+                                 " on status: {status}")).format(
+                                     status=job_execution.info['status'])
+    cluster = conductor.cluster_get(ctx, job_execution.cluster_id)
+    engine = get_job_engine(cluster, job_execution)
+    job_execution = conductor.job_execution_update(
+        ctx, job_execution_id, {
+            'info': {'status': edp.JOB_STATUS_TOBESUSPENDED}})
+    try:
+        job_info = engine.suspend_job(job_execution)
+    except Exception as ex:
+        job_info = None
+        conductor.job_execution_update(
+            ctx, job_execution_id, {'info': {
+                'status': edp.JOB_STATUS_SUSPEND_FAILED}})
+        raise e.SuspendingFailed(_("Error during suspending of job execution: "
+                                   "{error}")).format(error=ex)
+    if job_info is not None:
+        job_execution = _write_job_status(job_execution, job_info)
+        LOG.info(_LI("Job execution was suspended successfully"))
+        return job_execution
+
+    conductor.job_execution_update(
+        ctx, job_execution_id, {'info': {
+            'status': edp.JOB_STATUS_SUSPEND_FAILED}})
+    raise e.SuspendingFailed(_("Failed to suspend job execution"
+                               "{jid}")).format(jid=job_execution_id)
