@@ -24,6 +24,7 @@ from sahara import conductor as c
 from sahara import context
 from sahara import exceptions as e
 from sahara.i18n import _
+from sahara.service.castellan import utils as key_manager
 from sahara.service.edp import base_engine
 from sahara.service.edp.binary_retrievers import dispatch
 from sahara.service.edp import hdfs_helper as h
@@ -118,8 +119,8 @@ class SparkJobEngine(base_engine.JobEngine):
         if proxy_configs:
             configs[sw.HADOOP_SWIFT_USERNAME] = proxy_configs.get(
                 'proxy_username')
-            configs[sw.HADOOP_SWIFT_PASSWORD] = proxy_configs.get(
-                'proxy_password')
+            configs[sw.HADOOP_SWIFT_PASSWORD] = key_manager.get_secret(
+                proxy_configs.get('proxy_password'))
             configs[sw.HADOOP_SWIFT_TRUST_ID] = proxy_configs.get(
                 'proxy_trust_id')
             configs[sw.HADOOP_SWIFT_DOMAIN_NAME] = CONF.proxy_user_domain_name
@@ -175,11 +176,21 @@ class SparkJobEngine(base_engine.JobEngine):
 
         return uploaded_paths, builtin_paths
 
-    def _check_driver_class_path(self, param_dict):
+    def _check_driver_class_path(self, job_configs, param_dict, wf_dir):
+        overridden = edp.spark_driver_classpath(
+            job_configs.get('configs', {}))
+        if overridden:
+            param_dict['driver-class-path'] = (
+                " --driver-class-path " + overridden)
+            return
+        if not param_dict.get('wrapper_jar'):
+            # no need in driver classpath if swift as datasource is not used
+            param_dict['driver-class-path'] = ""
+            return
         cp = param_dict['driver-class-path'] or ""
         if param_dict['deploy-mode'] == 'client' and not (
                 cp.startswith(":") or cp.endswith(":")):
-            cp += ":"
+            cp += ":" + wf_dir
         param_dict['driver-class-path'] = " --driver-class-path " + cp
 
     def cancel_job(self, job_execution):
@@ -201,6 +212,7 @@ class SparkJobEngine(base_engine.JobEngine):
 
     def _build_command(self, wf_dir, paths, builtin_paths,
                        updated_job_configs):
+
         indep_params = {}
 
         # TODO(tmckay): for now, paths[0] is always assumed to be the app
@@ -210,7 +222,8 @@ class SparkJobEngine(base_engine.JobEngine):
         indep_params["app_jar"] = paths.pop(0)
         indep_params["job_class"] = (
             updated_job_configs["configs"]["edp.java.main_class"])
-
+        if self.plugin_params.get('drivers-to-jars', None):
+            paths.extend(self.plugin_params['drivers-to-jars'])
         # If we uploaded builtins then we are using a wrapper jar. It will
         # be the first one on the builtin list and the original app_jar needs
         # to be added to the  'additional' jars
@@ -252,7 +265,7 @@ class SparkJobEngine(base_engine.JobEngine):
         # Handle driver classpath. Because of the way the hadoop
         # configuration is handled in the wrapper class, using
         # wrapper_xml, the working directory must be on the classpath
-        self._check_driver_class_path(mutual_dict)
+        self._check_driver_class_path(updated_job_configs, mutual_dict, wf_dir)
 
         if mutual_dict.get("wrapper_jar"):
             # Substrings which may be empty have spaces
@@ -267,7 +280,7 @@ class SparkJobEngine(base_engine.JobEngine):
                 mutual_dict)
         else:
             cmd = (
-                '%(spark-user)s%(spark-submit)s'
+                '%(spark-user)s%(spark-submit)s%(driver-class-path)s'
                 ' --class %(job_class)s%(addnl_jars)s'
                 ' --master %(master)s'
                 ' --deploy-mode %(deploy-mode)s'
@@ -354,6 +367,10 @@ class SparkJobEngine(base_engine.JobEngine):
                            "%(status)s, stdout = %(stdout)s") %
                          {'status': ret, 'stdout': stdout})
 
+    def run_scheduled_job(self, job_execution):
+        raise e.NotImplementedException(_("Currently Spark engine does not"
+                                          " support scheduled EDP jobs"))
+
     def validate_job_execution(self, cluster, job, data):
         j.check_main_class_present(data, job)
 
