@@ -12,11 +12,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-try:
-    from tempest.lib.common.utils import data_utils
-except ImportError:
-    from tempest_lib.common.utils import data_utils
-from tempest import test
+from tempest.lib.common.utils import data_utils
 
 from sahara.tests.tempest.scenario.data_processing.client_tests import base
 
@@ -46,6 +42,18 @@ class DataSourceTest(base.BaseDataProcessingTest):
         self.assertEqual(source_name, source.name)
         self.assertDictContainsSubset(source_body, source.__dict__)
 
+    def _check_data_source_update(self, source_id):
+        values = {
+            'name': data_utils.rand_name('updated-sahara-data-source'),
+            'description': 'description',
+            'type': 'hdfs',
+            'url': 'hdfs://user/foo'
+        }
+
+        source = self.client.data_sources.update(source_id, values)
+
+        self.assertDictContainsSubset(values, source.data_source)
+
     def _check_data_source_delete(self, source_id):
         # delete data source
         self.client.data_sources.delete(source_id)
@@ -53,7 +61,6 @@ class DataSourceTest(base.BaseDataProcessingTest):
         source_list = self.client.data_sources.list()
         self.assertNotIn(source_id, [source.id for source in source_list])
 
-    @test.services('data_processing')
     def test_swift_data_source(self):
         # Create extra self.swift_data_source variable to use for comparison to
         # data source response body because response body has no 'credentials'
@@ -67,7 +74,6 @@ class DataSourceTest(base.BaseDataProcessingTest):
                                     self.swift_data_source)
         self._check_data_source_delete(source_id)
 
-    @test.services('data_processing')
     def test_local_hdfs_data_source(self):
         source_id, source_name = self._check_data_source_create(
             self.local_hdfs_data_source)
@@ -76,11 +82,11 @@ class DataSourceTest(base.BaseDataProcessingTest):
                                     self.local_hdfs_data_source)
         self._check_data_source_delete(source_id)
 
-    @test.services('data_processing')
     def test_external_hdfs_data_source(self):
         source_id, source_name = self._check_data_source_create(
             self.external_hdfs_data_source)
         self._check_data_source_list(source_id, source_name)
         self._check_data_source_get(source_id, source_name,
                                     self.external_hdfs_data_source)
+        self._check_data_source_update(source_id)
         self._check_data_source_delete(source_id)
