@@ -12,11 +12,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-try:
-    from tempest.lib.common.utils import data_utils
-except ImportError:
-    from tempest_lib.common.utils import data_utils
-from tempest import test
+from tempest.lib.common.utils import data_utils
 
 from sahara.tests.tempest.scenario.data_processing.client_tests import base
 
@@ -42,6 +38,14 @@ class JobBinaryInternalsTest(base.BaseDataProcessingTest):
         binary = self.client.job_binary_internals.get(binary_id)
         self.assertEqual(binary_name, binary.name)
 
+    def _check_job_binary_internal_update(self, binary_id):
+        values = {
+            'name': data_utils.rand_name('sahara-internal-job-binary'),
+            'is_public': True
+        }
+        binary = self.client.job_binary_internals.update(binary_id, **values)
+        self.assertDictContainsSubset(values, binary.job_binary_internal)
+
     def _check_job_binary_internal_delete(self, binary_id):
         # delete job binary internal by id
         self.client.job_binary_internals.delete(binary_id)
@@ -49,9 +53,9 @@ class JobBinaryInternalsTest(base.BaseDataProcessingTest):
         binary_list = self.client.job_binary_internals.list()
         self.assertNotIn(binary_id, [binary.id for binary in binary_list])
 
-    @test.services('data_processing')
     def test_job_binary_internal(self):
         binary_id, binary_name = self._check_job_binary_internal_create()
         self._check_job_binary_internal_list(binary_id, binary_name)
         self._check_job_binary_internal_get(binary_id, binary_name)
+        self._check_job_binary_internal_update(binary_id)
         self._check_job_binary_internal_delete(binary_id)
