@@ -12,11 +12,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-try:
-    from tempest.lib.common.utils import data_utils
-except ImportError:
-    from tempest_lib.common.utils import data_utils
-from tempest import test
+from tempest.lib.common.utils import data_utils
 
 from sahara.tests.tempest.scenario.data_processing.client_tests import base
 
@@ -50,6 +46,20 @@ class NodeGroupTemplateTest(base.BaseDataProcessingTest):
         self.assertDictContainsSubset(self.worker_template,
                                       template.__dict__)
 
+    def _check_node_group_template_update(self, template_id):
+        values = {
+            'name': data_utils.rand_name('updated-sahara-ng-template'),
+            'description': 'description',
+            'volumes_per_node': 2,
+            'volumes_size': 2,
+        }
+
+        resp_body = self.client.node_group_templates.update(template_id,
+                                                            **values)
+        # check that template updated successfully
+        self.assertDictContainsSubset(values,
+                                      resp_body.__dict__)
+
     def _check_node_group_template_delete(self, template_id):
         # delete node group template by id
         self.client.node_group_templates.delete(template_id)
@@ -58,9 +68,9 @@ class NodeGroupTemplateTest(base.BaseDataProcessingTest):
         templates = self.client.node_group_templates.list()
         self.assertNotIn(template_id, [template.id for template in templates])
 
-    @test.services('data_processing')
     def test_node_group_templates(self):
         template_id, template_name = self._check_create_node_group_template()
         self._check_node_group_template_list(template_id, template_name)
         self._check_node_group_template_get(template_id, template_name)
+        self._check_node_group_template_update(template_id)
         self._check_node_group_template_delete(template_id)
