@@ -15,13 +15,16 @@
 
 import copy
 
+import mock
 from sqlalchemy import exc as sa_exc
 import testtools
 
 from sahara.conductor import manager
 from sahara import context
+from sahara.db.sqlalchemy import models as m
 from sahara import exceptions as ex
 import sahara.tests.unit.conductor.base as test_base
+from sahara.utils import cluster as c_u
 
 
 SAMPLE_CLUSTER = {
@@ -58,6 +61,7 @@ SAMPLE_CLUSTER = {
             "config_1": "value_1"
         }
     },
+    "shares": [],
     "is_public": False,
     "is_protected": False
 }
@@ -152,15 +156,17 @@ class ClusterTest(test_base.ConductorManagerTestCase):
         cluster_db_obj = self.api.cluster_create(ctx, SAMPLE_CLUSTER)
         _id = cluster_db_obj["id"]
 
-        updated_cl = self.api.cluster_update(ctx, _id, {"status": "Active"})
+        updated_cl = self.api.cluster_update(
+            ctx, _id, {"status": c_u.CLUSTER_STATUS_ACTIVE})
         self.assertIsInstance(updated_cl, dict)
-        self.assertEqual("Active", updated_cl["status"])
+        self.assertEqual(c_u.CLUSTER_STATUS_ACTIVE, updated_cl["status"])
 
         get_cl_obj = self.api.cluster_get(ctx, _id)
         self.assertEqual(updated_cl, get_cl_obj)
 
         with testtools.ExpectedException(ex.NotFoundException):
-            self.api.cluster_update(ctx, "bad_id", {"status": "Active"})
+            self.api.cluster_update(
+                ctx, "bad_id", {"status": c_u.CLUSTER_STATUS_ACTIVE})
 
     def _ng_in_cluster(self, cluster_db_obj, ng_id):
         for ng in cluster_db_obj["node_groups"]:
@@ -349,18 +355,25 @@ class ClusterTest(test_base.ConductorManagerTestCase):
 
     def test_cluster_search(self):
         ctx = context.ctx()
-        self.api.cluster_create(ctx, SAMPLE_CLUSTER)
+        vals = copy.deepcopy(SAMPLE_CLUSTER)
+        vals['name'] = "test_name"
+        self.api.cluster_create(ctx, vals)
 
         lst = self.api.cluster_get_all(ctx)
         self.assertEqual(1, len(lst))
 
-        kwargs = {'name': SAMPLE_CLUSTER['name'],
-                  'plugin_name': SAMPLE_CLUSTER['plugin_name']}
+        kwargs = {'name': vals['name'],
+                  'plugin_name': vals['plugin_name']}
         lst = self.api.cluster_get_all(ctx, **kwargs)
         self.assertEqual(1, len(lst))
 
         # Valid field but no matching value
-        kwargs = {'name': SAMPLE_CLUSTER['name']+'foo'}
+        kwargs = {'name': vals['name']+'foo'}
+        lst = self.api.cluster_get_all(ctx, **kwargs)
+        self.assertEqual(0, len(lst))
+
+        # Valid field with substrings
+        kwargs = {'name': 'test'}
         lst = self.api.cluster_get_all(ctx, **kwargs)
         self.assertEqual(0, len(lst))
 
@@ -368,3 +381,44 @@ class ClusterTest(test_base.ConductorManagerTestCase):
         self.assertRaises(sa_exc.InvalidRequestError,
                           self.api.cluster_get_all,
                           ctx, **{'badfield': 'somevalue'})
+
+    @mock.patch('sahara.db.sqlalchemy.api.regex_filter')
+    def test_cluster_search_regex(self, regex_filter):
+
+        # do this so we can return the correct value
+        def _regex_filter(query, cls, regex_cols, search_opts):
+            return query, search_opts
+
+        regex_filter.side_effect = _regex_filter
+
+        ctx = context.ctx()
+        self.api.cluster_get_all(ctx)
+        self.assertEqual(0, regex_filter.call_count)
+
+        self.api.cluster_get_all(ctx, regex_search=True, name="fox")
+        self.assertEqual(1, regex_filter.call_count)
+        args, kwargs = regex_filter.call_args
+        self.assertTrue(type(args[1] is m.Cluster))
+        self.assertEqual(args[2], ["name", "description", "plugin_name"])
+        self.assertEqual(args[3], {"name": "fox"})
+
+    @mock.patch("sahara.service.shares.mount_shares")
+    def test_cluster_update_shares(self, mount_shares):
+        ctx = context.ctx()
+        cluster_db_obj = self.api.cluster_create(ctx, SAMPLE_CLUSTER)
+        _id = cluster_db_obj["id"]
+
+        test_shares = [
+            {
+                "id": "bd71d2d5-60a0-4ed9-a3d2-ad312c368880",
+                "path": "/mnt/manila",
+                "access_level": "rw"
+            }
+        ]
+
+        updated_cl = self.api.cluster_update(ctx, _id, {"shares": test_shares})
+        self.assertIsInstance(updated_cl, dict)
+        self.assertEqual(test_shares, updated_cl["shares"])
+
+        get_cl_obj = self.api.cluster_get(ctx, _id)
+        self.assertEqual(updated_cl, get_cl_obj)
