@@ -78,7 +78,8 @@ worker_json = {
 
 
 class Config(c.Config):
-    def __init__(self, option_values={}):
+    def __init__(self, option_values=None):
+        option_values = option_values or {}
         if "name" not in option_values:
             option_values["name"] = "update"
         super(Config, self).__init__(option_values)
@@ -386,9 +387,9 @@ class TemplateUpdateTestCase(base.ConductorManagerTestCase):
         self.assertIn(msg, self.logger.infos)
 
         self.api.node_group_template_destroy(ctx, new["id"],
-                                             ignore_default=True)
+                                             ignore_prot_on_def=True)
         self.api.node_group_template_destroy(ctx, existing["id"],
-                                             ignore_default=True)
+                                             ignore_prot_on_def=True)
 
     @mock.patch("sahara.conductor.API.node_group_template_update")
     @mock.patch("sahara.db.templates.api.reverse_node_group_template_creates")
@@ -431,9 +432,9 @@ class TemplateUpdateTestCase(base.ConductorManagerTestCase):
         self.assertIn(msg, self.logger.warnings)
 
         self.api.node_group_template_destroy(ctx, new["id"],
-                                             ignore_default=True)
+                                             ignore_prot_on_def=True)
         self.api.node_group_template_destroy(ctx, existing["id"],
-                                             ignore_default=True)
+                                             ignore_prot_on_def=True)
 
     @mock.patch("sahara.conductor.API.node_group_template_create")
     @mock.patch("sahara.db.templates.api.reverse_node_group_template_creates")
@@ -475,7 +476,7 @@ class TemplateUpdateTestCase(base.ConductorManagerTestCase):
         self.assertIn(msg, self.logger.warnings)
 
         self.api.node_group_template_destroy(ctx, existing["id"],
-                                             ignore_default=True)
+                                             ignore_prot_on_def=True)
 
     def test_add_cluster_templates(self):
         self.logger.clear_log()
@@ -511,9 +512,9 @@ class TemplateUpdateTestCase(base.ConductorManagerTestCase):
         self.assertIn(msg, self.logger.infos)
 
         self.api.cluster_template_destroy(ctx, new["id"],
-                                          ignore_default=True)
+                                          ignore_prot_on_def=True)
         self.api.cluster_template_destroy(ctx, existing["id"],
-                                          ignore_default=True)
+                                          ignore_prot_on_def=True)
 
     @mock.patch("sahara.conductor.API.cluster_template_update")
     @mock.patch("sahara.db.templates.api.reverse_cluster_template_creates")
@@ -556,9 +557,9 @@ class TemplateUpdateTestCase(base.ConductorManagerTestCase):
         self.assertIn(msg, self.logger.warnings)
 
         self.api.cluster_template_destroy(ctx, new["id"],
-                                          ignore_default=True)
+                                          ignore_prot_on_def=True)
         self.api.cluster_template_destroy(ctx, existing["id"],
-                                          ignore_default=True)
+                                          ignore_prot_on_def=True)
 
     @mock.patch("sahara.conductor.API.cluster_template_create")
     @mock.patch("sahara.db.templates.api.reverse_cluster_template_creates")
@@ -604,7 +605,7 @@ class TemplateUpdateTestCase(base.ConductorManagerTestCase):
         self.assertIn(msg, self.logger.warnings)
 
         self.api.cluster_template_destroy(ctx, existing["id"],
-                                          ignore_default=True)
+                                          ignore_prot_on_def=True)
 
     @mock.patch("sahara.db.templates.api.get_configs")
     @mock.patch("sahara.db.templates.api.add_config_section_for_template")
