@@ -20,10 +20,12 @@ from oslo_utils import timeutils
 
 from sahara.conductor import manager
 from sahara import context
+from sahara.service.castellan import config as castellan
 import sahara.service.periodic as p
 import sahara.tests.unit.base as base
 from sahara.tests.unit.conductor.manager import test_clusters as tc
 from sahara.tests.unit.conductor.manager import test_edp as te
+from sahara.utils import cluster as c_u
 
 
 class TestPeriodicBack(base.SaharaWithDbTestCase):
@@ -31,6 +33,7 @@ class TestPeriodicBack(base.SaharaWithDbTestCase):
     def setUp(self):
         super(TestPeriodicBack, self).setUp()
         self.api = manager.ConductorManager()
+        castellan.validate_config()
 
     @mock.patch('sahara.service.edp.job_manager.get_job_status')
     def test_job_status_update(self, get_job_status):
@@ -52,7 +55,7 @@ class TestPeriodicBack(base.SaharaWithDbTestCase):
                                          mock.call(u'3')])
 
     @mock.patch('sahara.service.trusts.use_os_admin_auth_token')
-    @mock.patch('sahara.service.ops.terminate_cluster')
+    @mock.patch('sahara.service.api.terminate_cluster')
     def test_transient_cluster_terminate(self, terminate_cluster,
                                          use_os_admin_auth_token):
 
@@ -85,7 +88,7 @@ class TestPeriodicBack(base.SaharaWithDbTestCase):
         terminate_cluster.assert_has_calls([mock.call(u'1')])
         self.assertEqual(1, use_os_admin_auth_token.call_count)
 
-    @mock.patch('sahara.service.ops.terminate_cluster')
+    @mock.patch('sahara.service.api.terminate_cluster')
     def test_not_transient_cluster_does_not_terminate(self, terminate_cluster):
 
         timeutils.set_time_override(datetime.datetime(2005, 2, 1, 0, 0))
@@ -95,7 +98,7 @@ class TestPeriodicBack(base.SaharaWithDbTestCase):
 
         self.assertEqual(0, terminate_cluster.call_count)
 
-    @mock.patch('sahara.service.ops.terminate_cluster')
+    @mock.patch('sahara.service.api.terminate_cluster')
     def test_transient_cluster_not_killed_too_early(self, terminate_cluster):
 
         timeutils.set_time_override(datetime.datetime(2005, 2, 1, second=0))
@@ -108,7 +111,7 @@ class TestPeriodicBack(base.SaharaWithDbTestCase):
         self.assertEqual(0, terminate_cluster.call_count)
 
     @mock.patch('sahara.service.trusts.use_os_admin_auth_token')
-    @mock.patch('sahara.service.ops.terminate_cluster')
+    @mock.patch('sahara.service.api.terminate_cluster')
     def test_transient_cluster_killed_in_time(self, terminate_cluster,
                                               use_os_admin_auth_token):
 
@@ -123,14 +126,14 @@ class TestPeriodicBack(base.SaharaWithDbTestCase):
         terminate_cluster.assert_has_calls([mock.call(u'1')])
         self.assertEqual(1, use_os_admin_auth_token.call_count)
 
-    @mock.patch('sahara.service.ops.terminate_cluster')
+    @mock.patch('sahara.service.api.terminate_cluster')
     def test_incomplete_cluster_not_killed_too_early(self, terminate_cluster):
 
         self.override_config('cleanup_time_for_incomplete_clusters', 1)
 
         timeutils.set_time_override(datetime.datetime(2005, 2, 1, second=0))
 
-        self._make_cluster('1', status='Pending')
+        self._make_cluster('1', c_u.CLUSTER_STATUS_SPAWNING)
 
         timeutils.set_time_override(datetime.datetime(
             2005, 2, 1, minute=59, second=50))
@@ -139,14 +142,14 @@ class TestPeriodicBack(base.SaharaWithDbTestCase):
         self.assertEqual(0, terminate_cluster.call_count)
 
     @mock.patch('sahara.service.trusts.use_os_admin_auth_token')
-    @mock.patch('sahara.service.ops.terminate_cluster')
+    @mock.patch('sahara.service.api.terminate_cluster')
     def test_incomplete_cluster_killed_in_time(self, terminate_cluster,
                                                use_os_admin_auth_token):
 
         self.override_config('cleanup_time_for_incomplete_clusters', 1)
         timeutils.set_time_override(datetime.datetime(2005, 2, 1, second=0))
 
-        self._make_cluster('1', status='Pending')
+        self._make_cluster('1', c_u.CLUSTER_STATUS_SPAWNING)
 
         timeutils.set_time_override(datetime.datetime(
             2005, 2, 1, hour=1, second=10))
@@ -156,7 +159,7 @@ class TestPeriodicBack(base.SaharaWithDbTestCase):
         terminate_cluster.assert_has_calls([mock.call(u'1')])
         self.assertEqual(1, use_os_admin_auth_token.call_count)
 
-    @mock.patch('sahara.service.ops.terminate_cluster')
+    @mock.patch('sahara.service.api.terminate_cluster')
     def test_active_cluster_not_killed_as_inactive(
             self, terminate_cluster):
         self.override_config('cleanup_time_for_incomplete_clusters', 1)
@@ -205,12 +208,33 @@ class TestPeriodicBack(base.SaharaWithDbTestCase):
 
         mock_user_delete.assert_called_once_with(user_id=1)
 
+    @mock.patch(
+        'sahara.service.health.verification_base.validate_verification_start')
+    @mock.patch('sahara.service.api.update_cluster')
+    def test_run_verifications_executed(self, cluster_update, ver_valid):
+        self._make_cluster('1')
+        p._make_periodic_tasks().run_verifications(None)
+        self.assertEqual(1, ver_valid.call_count)
+        cluster_update.assert_called_once_with(
+            '1', {'verification': {'status': 'START'}})
+
+    @mock.patch(
+        'sahara.service.health.verification_base.validate_verification_start')
+    @mock.patch('sahara.service.api.update_cluster')
+    def test_run_verifications_not_executed(self, cluster_update, ver_valid):
+        self._make_cluster('1', status=c_u.CLUSTER_STATUS_ERROR)
+        p._make_periodic_tasks().run_verifications(None)
+        ver_valid.assert_not_called()
+        cluster_update.assert_not_called()
+
     @mock.patch("sahara.service.periodic.threadgroup")
     @mock.patch("sahara.service.periodic.CONF")
     def test_setup_enabled(self, mock_conf, mock_thread_group):
         mock_conf.periodic_enable = True
         mock_conf.periodic_fuzzy_delay = 20
         mock_conf.periodic_interval_max = 30
+        mock_conf.periodic_workers_number = 1
+        mock_conf.periodic_coordinator_backend_url = ''
 
         add_timer = mock_thread_group.ThreadGroup().add_dynamic_timer
 
@@ -229,7 +253,9 @@ class TestPeriodicBack(base.SaharaWithDbTestCase):
 
         self.assertFalse(add_timer._mock_called)
 
-    def _make_cluster(self, id_name, status='Active', is_transient=True):
+    def _make_cluster(self, id_name, status=c_u.CLUSTER_STATUS_ACTIVE,
+
+                      is_transient=True):
         ctx = context.ctx()
 
         c = tc.SAMPLE_CLUSTER.copy()
