@@ -25,6 +25,7 @@ from sahara.service.validations import clusters_scaling as c_s
 from sahara.service.validations import clusters_schema as c_schema
 from sahara.tests.unit.service.validation import utils as u
 from sahara.tests.unit import testutils as tu
+from sahara.utils import cluster as c_u
 
 
 def _get_plugin(plugin_name):
@@ -67,17 +68,20 @@ class TestScalingValidation(u.ValidationTestCase):
         ops.get_engine_type_and_version.return_value = "direct.1.1"
         ng1 = tu.make_ng_dict('ng', '42', ['namenode'], 1)
         cluster = tu.create_cluster("cluster1", "tenant1", "fake", "0.1",
-                                    [ng1], status='Validating', id='12321')
+                                    [ng1],
+                                    status=c_u.CLUSTER_STATUS_VALIDATING,
+                                    id='12321')
 
         self._assert_check_scaling(
             data={}, cluster=cluster,
             expected_message="Cluster cannot be scaled "
-                             "not in 'Active' "
-                             "status. Cluster status: "
-                             "Validating")
+                             "not in '" + c_u.CLUSTER_STATUS_ACTIVE +
+            "' status. Cluster status: " +
+            c_u.CLUSTER_STATUS_VALIDATING)
 
         cluster = tu.create_cluster("cluster1", "tenant1", "fake", "0.1",
-                                    [ng1], status='Active', id='12321')
+                                    [ng1], status=c_u.CLUSTER_STATUS_ACTIVE,
+                                    id='12321')
         data = {
             'resize_node_groups': [
                 {
@@ -113,7 +117,8 @@ class TestScalingValidation(u.ValidationTestCase):
         ops.get_engine_type_and_version.return_value = "direct.1.1"
         ng1 = tu.make_ng_dict('ng', '42', ['namenode'], 1)
         cluster = tu.create_cluster("test-cluster", "tenant1", "fake",
-                                    "0.1", [ng1], status='Active',
+                                    "0.1",
+                                    [ng1], status=c_u.CLUSTER_STATUS_ACTIVE,
                                     id='12321')
         data = {
             'add_node_groups': [
@@ -202,7 +207,7 @@ class TestScalingValidation(u.ValidationTestCase):
         self._assert_cluster_scaling_validation(
             data=data,
             bad_req_i=(1, 'VALIDATION_ERROR',
-                       u"'name' is a required property")
+                       u"resize_node_groups[0]: 'name' is a required property")
         )
         data = {
             'resize_node_groups': [
@@ -214,7 +219,8 @@ class TestScalingValidation(u.ValidationTestCase):
         self._assert_cluster_scaling_validation(
             data=data,
             bad_req_i=(1, 'VALIDATION_ERROR',
-                       u"'count' is a required property")
+                       u"resize_node_groups[0]: 'count' is a required "
+                       u"property")
         )
 
     @mock.patch("sahara.service.api.OPS")
@@ -231,7 +237,7 @@ class TestScalingValidation(u.ValidationTestCase):
         self._assert_cluster_scaling_validation(
             data=data,
             bad_req_i=(1, 'VALIDATION_ERROR',
-                       "{'node_group_template_id': "
+                       "add_node_groups[0]: {'node_group_template_id': "
                        "'5185a809-6bf7-44ed-9de3-618270550e2c'} "
                        "is not valid under any of the given schemas")
         )
@@ -247,7 +253,7 @@ class TestScalingValidation(u.ValidationTestCase):
         self._assert_cluster_scaling_validation(
             data=data,
             bad_req_i=(1, 'VALIDATION_ERROR',
-                       u"{'node_group_template_id': "
+                       u"add_node_groups[0]: {'node_group_template_id': "
                        u"'5185a809-6bf7-44ed-9de3-618270550e2c', "
                        u"'name': 'a'} is not valid under any "
                        u"of the given schemas")
@@ -309,7 +315,7 @@ class TestScalingValidation(u.ValidationTestCase):
         self._assert_cluster_scaling_validation(
             data=data,
             bad_req_i=(1, 'VALIDATION_ERROR',
-                       u"{} is not of type 'array'")
+                       u"resize_node_groups: {} is not of type 'array'")
         )
         data = {
             'add_node_groups': {}
@@ -317,7 +323,7 @@ class TestScalingValidation(u.ValidationTestCase):
         self._assert_cluster_scaling_validation(
             data=data,
             bad_req_i=(1, 'VALIDATION_ERROR',
-                       u"{} is not of type 'array'")
+                       u"add_node_groups: {} is not of type 'array'")
         )
         data = {
             'resize_node_groups': [],
@@ -325,7 +331,7 @@ class TestScalingValidation(u.ValidationTestCase):
         self._assert_cluster_scaling_validation(
             data=data,
             bad_req_i=(1, 'VALIDATION_ERROR',
-                       u'[] is too short')
+                       u'resize_node_groups: [] is too short')
         )
 
     @mock.patch("sahara.service.api.OPS")
@@ -360,7 +366,7 @@ class TestScalingValidation(u.ValidationTestCase):
         ng1 = tu.make_ng_dict('ng', '42', ['namenode'], 1)
         cluster = tu.create_cluster(
             "cluster1", "tenant1", "fake", "0.1", [ng1],
-            status='Active', id='12321',
+            status=c_u.CLUSTER_STATUS_ACTIVE, id='12321',
             sahara_info={"infrastructure_engine": "heat.1.1"})
 
         self._assert_check_scaling(
@@ -373,7 +379,8 @@ class TestScalingValidation(u.ValidationTestCase):
         ops.get_engine_type_and_version.return_value = "heat.1.1"
         ng1 = tu.make_ng_dict('ng', '42', ['namenode'], 1)
         cluster = tu.create_cluster("cluster1", "tenant1", "fake", "0.1",
-                                    [ng1], status='Active', id='12321')
+                                    [ng1], status=c_u.CLUSTER_STATUS_ACTIVE,
+                                    id='12321')
 
         self._assert_check_scaling(
             data={}, cluster=cluster,
