@@ -14,7 +14,7 @@
 # limitations under the License.
 
 import os
-import pickle
+import pickle  # nosec
 import sys
 
 from eventlet.green import subprocess
@@ -39,15 +39,19 @@ def start_subprocess():
                             stderr=subprocess.PIPE)
 
 
-def run_in_subprocess(proc, func, args=(), kwargs={}, interactive=False):
+def run_in_subprocess(proc, func, args=None, kwargs=None, interactive=False):
+    args = args or ()
+    kwargs = kwargs or {}
     try:
-        pickle.dump(func, proc.stdin)
-        pickle.dump(args, proc.stdin)
-        pickle.dump(kwargs, proc.stdin)
+        # TODO(elmiko) these pickle usages should be reinvestigated to
+        # determine a more secure manner to deploy remote commands.
+        pickle.dump(func, proc.stdin)  # nosec
+        pickle.dump(args, proc.stdin)  # nosec
+        pickle.dump(kwargs, proc.stdin)  # nosec
         proc.stdin.flush()
 
         if not interactive:
-            result = pickle.load(proc.stdout)
+            result = pickle.load(proc.stdout)  # nosec
 
             if 'exception' in result:
                 raise exceptions.SubprocessException(result['exception'])
@@ -89,6 +93,7 @@ def kill_subprocess(proc):
 
     try:
         proc.kill()
+        proc.wait()
     except OSError:
         # could be caused by process already dead, so ignoring
         pass
