@@ -54,6 +54,7 @@ from sahara import context
 from sahara import exceptions as ex
 from sahara.i18n import _
 from sahara.i18n import _LE
+from sahara.service import trusts
 from sahara.utils import crypto
 from sahara.utils.openstack import neutron
 from sahara.utils import procutils
@@ -108,7 +109,7 @@ def _connect(host, username, private_key, proxy_command=None,
     global _proxy_ssh
 
     LOG.debug('Creating SSH connection')
-    if type(private_key) in [str, unicode]:
+    if isinstance(private_key, six.string_types):
         private_key = crypto.to_paramiko_private_key(private_key)
 
     _ssh = paramiko.SSHClient()
@@ -524,7 +525,7 @@ class NetcatSocket(object):
 
     def _terminate(self):
         if self.rootwrap_command:
-            os.system('{0} kill {1}'.format(self.rootwrap_command,
+            os.system('{0} kill {1}'.format(self.rootwrap_command,  # nosec
                                             self.process.pid))
         else:
             self.process.terminate()
@@ -572,7 +573,7 @@ class InstanceInteropHelper(remote.Remote):
         neutron_info = dict()
         neutron_info['network'] = instance.cluster.neutron_management_network
         ctx = context.current()
-        neutron_info['token'] = ctx.auth_token
+        neutron_info['token'] = context.get_auth_token()
         neutron_info['tenant'] = ctx.tenant_name
         neutron_info['host'] = instance.management_ip
 
@@ -594,8 +595,9 @@ class InstanceInteropHelper(remote.Remote):
 
         # Query Neutron only if needed
         if '{router_id}' in command:
+            auth = trusts.get_os_admin_auth_plugin(instance.cluster)
             client = neutron.NeutronClient(info['network'], info['token'],
-                                           info['tenant'])
+                                           info['tenant'], auth=auth)
             keywords['router_id'] = client.get_router()
 
         keywords['host'] = instance.management_ip
@@ -751,7 +753,7 @@ class InstanceInteropHelper(remote.Remote):
         self._run_s(_write_file_to, timeout, remote_file, data, run_as_root)
 
     def write_files_to(self, files, run_as_root=False, timeout=None):
-        self._log_command('Writing files "%s"' % files.keys())
+        self._log_command('Writing files "%s"' % list(files.keys()))
         self._run_s(_write_files_to, timeout, files, run_as_root)
 
     def append_to_file(self, r_file, data, run_as_root=False, timeout=None):
@@ -759,7 +761,7 @@ class InstanceInteropHelper(remote.Remote):
         self._run_s(_append_to_file, timeout, r_file, data, run_as_root)
 
     def append_to_files(self, files, run_as_root=False, timeout=None):
-        self._log_command('Appending to files "%s"' % files.keys())
+        self._log_command('Appending to files "%s"' % list(files.keys()))
         self._run_s(_append_to_files, timeout, files, run_as_root)
 
     def read_file_from(self, remote_file, run_as_root=False, timeout=None):
